@@ -390,7 +390,11 @@ class Ruleset
             $includedSniffs = array_merge($includedSniffs, $expandedSniffs);
 
             $parts = explode('.', $rule['ref']);
-            if (count($parts) === 4) {
+            if (count($parts) === 4
+                && $parts[0] !== ''
+                && $parts[1] !== ''
+                && $parts[2] !== ''
+            ) {
                 $sniffCode = $parts[0].'.'.$parts[1].'.'.$parts[2];
                 if (isset($this->ruleset[$sniffCode]['severity']) === true
                     && $this->ruleset[$sniffCode]['severity'] === 0
@@ -946,6 +950,13 @@ class Ruleset
                         && (string) $prop['type'] === 'array'
                     ) {
                         $values = [];
+                        if (isset($prop['extend']) === true
+                            && (string) $prop['extend'] === 'true'
+                            && isset($this->ruleset[$code]['properties'][$name]) === true
+                        ) {
+                            $values = $this->ruleset[$code]['properties'][$name];
+                        }
+
                         if (isset($prop->element) === true) {
                             $printValue = '';
                             foreach ($prop->element as $element) {
