@@ -25,7 +25,7 @@ class CyclomaticComplexityUnitTest extends AbstractSniffUnitTest
      */
     public function getErrorList()
     {
-        return array(116 => 1);
+        return [116 => 1];
 
     }//end getErrorList()
 
@@ -40,10 +40,10 @@ class CyclomaticComplexityUnitTest extends AbstractSniffUnitTest
      */
     public function getWarningList()
     {
-        return array(
-                45 => 1,
-                72 => 1,
-               );
+        return [
+            45 => 1,
+            72 => 1,
+        ];
 
     }//end getWarningList()
 
