@@ -42,18 +42,6 @@ class DisallowAlternativePHPTagsUnitTest extends AbstractSniffUnitTest
     }//end getTestFiles()
 
 
-    /**
-     * Skip this test on HHVM.
-     *
-     * @return bool Whether to skip this test.
-     */
-    protected function shouldSkipTest()
-    {
-        return defined('HHVM_VERSION');
-
-    }//end shouldSkipTest()
-
-
     /**
      * Returns the lines where errors should occur.
      *
