@@ -77,9 +77,9 @@ class OperatorBracketSniff implements Sniff
             if ($tokens[$number]['code'] === T_LNUMBER || $tokens[$number]['code'] === T_DNUMBER) {
                 $previous = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true);
                 if ($previous !== false) {
-                    $isAssignment = in_array($tokens[$previous]['code'], Tokens::$assignmentTokens);
-                    $isEquality   = in_array($tokens[$previous]['code'], Tokens::$equalityTokens);
-                    $isComparison = in_array($tokens[$previous]['code'], Tokens::$comparisonTokens);
+                    $isAssignment = isset(Tokens::$assignmentTokens[$tokens[$previous]['code']]);
+                    $isEquality   = isset(Tokens::$equalityTokens[$tokens[$previous]['code']]);
+                    $isComparison = isset(Tokens::$comparisonTokens[$tokens[$previous]['code']]);
                     if ($isAssignment === true || $isEquality === true || $isComparison === true) {
                         // This is a negative assignment or comparison.
                         // We need to check that the minus and the number are
@@ -100,15 +100,16 @@ class OperatorBracketSniff implements Sniff
             // A list of tokens that indicate that the token is not
             // part of an arithmetic operation.
             $invalidTokens = [
-                T_COMMA,
-                T_COLON,
-                T_OPEN_PARENTHESIS,
-                T_OPEN_SQUARE_BRACKET,
-                T_OPEN_SHORT_ARRAY,
-                T_CASE,
+                T_COMMA               => true,
+                T_COLON               => true,
+                T_OPEN_PARENTHESIS    => true,
+                T_OPEN_SQUARE_BRACKET => true,
+                T_OPEN_CURLY_BRACKET  => true,
+                T_OPEN_SHORT_ARRAY    => true,
+                T_CASE                => true,
             ];
 
-            if (in_array($tokens[$previousToken]['code'], $invalidTokens) === true) {
+            if (isset($invalidTokens[$tokens[$previousToken]['code']]) === true) {
                 return;
             }
         }
@@ -122,7 +123,7 @@ class OperatorBracketSniff implements Sniff
                 && $tokens[$tokens[$lastBracket]['parenthesis_owner']]['code'] === T_CATCH
             ) {
                 // This is a pipe character inside a catch statement, so it is acting
-                // as an exception type seperator and not an arithmetic operation.
+                // as an exception type separator and not an arithmetic operation.
                 return;
             }
         }
@@ -143,6 +144,7 @@ class OperatorBracketSniff implements Sniff
             T_CLOSE_SQUARE_BRACKET,
             T_MODULUS,
             T_NONE,
+            T_BITWISE_NOT,
         ];
 
         $allowed += Tokens::$operators;
@@ -268,20 +270,23 @@ class OperatorBracketSniff implements Sniff
         $tokens = $phpcsFile->getTokens();
 
         $allowed = [
-            T_VARIABLE        => true,
-            T_LNUMBER         => true,
-            T_DNUMBER         => true,
-            T_STRING          => true,
-            T_WHITESPACE      => true,
-            T_NS_SEPARATOR    => true,
-            T_THIS            => true,
-            T_SELF            => true,
-            T_OBJECT_OPERATOR => true,
-            T_DOUBLE_COLON    => true,
-            T_MODULUS         => true,
-            T_ISSET           => true,
-            T_ARRAY           => true,
-            T_NONE            => true,
+            T_VARIABLE                 => true,
+            T_LNUMBER                  => true,
+            T_DNUMBER                  => true,
+            T_STRING                   => true,
+            T_CONSTANT_ENCAPSED_STRING => true,
+            T_DOUBLE_QUOTED_STRING     => true,
+            T_WHITESPACE               => true,
+            T_NS_SEPARATOR             => true,
+            T_THIS                     => true,
+            T_SELF                     => true,
+            T_OBJECT_OPERATOR          => true,
+            T_DOUBLE_COLON             => true,
+            T_MODULUS                  => true,
+            T_ISSET                    => true,
+            T_ARRAY                    => true,
+            T_NONE                     => true,
+            T_BITWISE_NOT              => true,
         ];
 
         // Find the first token in the expression.
@@ -323,7 +328,7 @@ class OperatorBracketSniff implements Sniff
         // Find the last token in the expression.
         for ($after = ($stackPtr + 1); $after < $phpcsFile->numTokens; $after++) {
             // Special case for plus operators because we can't tell if they are used
-            // for addition or string contact. So assume string concat to be safe.
+            // for addition or string concat. So assume string concat to be safe.
             if ($phpcsFile->tokenizerType === 'JS' && $tokens[$after]['code'] === T_PLUS) {
                 break;
             }
@@ -356,7 +361,7 @@ class OperatorBracketSniff implements Sniff
 
         $after = $phpcsFile->findPrevious(Tokens::$emptyTokens, ($after - 1), null, true);
 
-        $error = 'Arithmetic operation must be bracketed';
+        $error = 'Operation must be bracketed';
         if ($before === $after || $before === $stackPtr || $after === $stackPtr) {
             $phpcsFile->addError($error, $stackPtr, 'MissingBrackets');
             return;
