@@ -25,14 +25,14 @@ class LowercaseClassKeywordsUnitTest extends AbstractSniffUnitTest
      */
     public function getErrorList()
     {
-        $errors = array(
-                   2  => 3,
-                   3  => 3,
-                   4  => 1,
-                   5  => 1,
-                   9  => 1,
-                   10 => 1,
-                  );
+        $errors = [
+            2  => 3,
+            3  => 3,
+            4  => 1,
+            5  => 1,
+            9  => 1,
+            10 => 1,
+        ];
 
         return $errors;
 
@@ -49,7 +49,7 @@ class LowercaseClassKeywordsUnitTest extends AbstractSniffUnitTest
      */
     public function getWarningList()
     {
-        return array();
+        return [];
 
     }//end getWarningList()
 
